@@ -2,8 +2,8 @@
 # -*- coding: utf-8 -*-
 
 ###################
-#    This tool run scripts and display the result in a Web Interface.
-#    Copyright (C) 2021, 2022  Maurice Lambert
+#    This tool runs CLI scripts and displays output in a Web Interface.
+#    Copyright (C) 2021, 2022, 2023  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,19 +20,19 @@
 ###################
 
 """
-This tool run scripts and display the result in a Web Interface.
+This tool runs CLI scripts and displays output in a Web Interface.
 
 This file implement the hardening audit of the WebScripts installation and
 configuration.
 """
 
-__version__ = "1.1.2"
+__version__ = "1.1.4"
 __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
 __description__ = """
-This tool run scripts and display the result in a Web Interface.
+This tool runs CLI scripts and displays output in a Web Interface.
 
 This file implement the hardening audit of the WebScripts installation and
 configuration.
@@ -41,7 +41,7 @@ license = "GPL-3.0 License"
 __url__ = "https://github.com/mauricelambert/WebScripts"
 
 copyright = """
-WebScripts  Copyright (C) 2021, 2022  Maurice Lambert
+WebScripts  Copyright (C) 2021, 2022, 2023  Maurice Lambert
 This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions.
@@ -174,7 +174,6 @@ class Report:
     def truncate_string(
         string: str, length: int = 13, end: str = "...", separator: str = ","
     ) -> str:
-
         """
         This function truncate a string.
         """
@@ -192,7 +191,6 @@ class Report:
         return string
 
     def as_json(self) -> str:
-
         """
         This function returns a JSON string of audit results.
         """
@@ -219,7 +217,6 @@ class Report:
         }
 
         for rule in self.rules:
-
             audit = {}
             self.reports_dict["ALL"].append(audit)
             self.reports_dict[rule.severity].append(audit)
@@ -232,7 +229,6 @@ class Report:
                 scoring[f"{rule.severity} fail"] += rule.level
 
             for attribut in Rule.__dataclass_fields__.keys():
-
                 if attribut == "is_OK":
                     new_attribut = "state"
                     new_value = "PASS" if getattr(rule, attribut) else "FAIL"
@@ -265,7 +261,6 @@ class Report:
         return self.reports_json
 
     def get_pourcent(self) -> None:
-
         """
         This function calcul pourcent.
         """
@@ -274,7 +269,9 @@ class Report:
 
         self.pourcent = {
             s.value: 100
-            - scoring[f"{s.value} fail"] * 100 / scoring[f"{s.value} total"]
+            - scoring[f"{s.value} fail"]
+            * 100
+            / (scoring[f"{s.value} total"] or 1)
             for s in SEVERITY
         }
         self.pourcent["ALL"] = 100 - GETTER.fail(scoring) * 100 / GETTER.total(
@@ -283,7 +280,6 @@ class Report:
 
     @staticmethod
     def get_HTML_table(headers: str, rules: List[Rule]) -> str:
-
         """
         This function returns a HTML table with rule attributes as columns.
         """
@@ -299,8 +295,9 @@ class Report:
         return table
 
     def as_html(self) -> str:
-
-        """This function return a HTML string of audit results."""
+        """
+        This function return a HTML string of audit results.
+        """
 
         G = GETTER
         scoring = G.score(self.reports_dict)
@@ -519,7 +516,6 @@ class Report:
     def get_text_table(
         headers: str, rules: List[Rule], joiner: str = "    "
     ) -> str:
-
         """
         This function return a text table with rule attributes as columns.
         """
@@ -535,7 +531,6 @@ class Report:
         )
 
     def as_text(self) -> str:
-
         """This function return a HTML string of audit results."""
 
         if self.reports_dict is None:
@@ -621,7 +616,6 @@ scoring[f"{SEVERITY.INFORMATION.value} total"]:0>4},  Fail:\
         return self.reports_text
 
     def notification(self) -> None:
-
         """
         This function send an email notification
         to administrator with the audit report.
@@ -689,7 +683,6 @@ class Audit:
     latest = []
 
     def audit_in_venv(server: Server) -> Rule:
-
         """
         This function checks the virtualenv.
         """
@@ -705,7 +698,6 @@ class Audit:
         )
 
     def audit_config_files(server: Server) -> Rule:
-
         """
         This function checks the configurations files.
         """
@@ -736,7 +728,6 @@ class Audit:
         )
 
     def audit_venv_modules(server: Server) -> Rule:
-
         """
         This function checks the virtualenv modules.
         """
@@ -925,7 +916,6 @@ class Audit:
         )
 
     def audit_system_user(server: Server) -> Rule:
-
         """
         This function checks the user.
         """
@@ -946,7 +936,6 @@ class Audit:
         )
 
     def audit_interface(server: Server) -> Rule:
-
         """
         This function checks the network interface.
         """
@@ -962,8 +951,9 @@ class Audit:
         )
 
     def audit_force_auth(server: Server) -> Rule:
-
-        """This function checks authentication is forced."""
+        """
+        This function checks authentication is forced.
+        """
 
         return Rule(
             "Force authentication",
@@ -977,7 +967,6 @@ class Audit:
         )
 
     def audit_active_auth(server: Server) -> Rule:
-
         """
         This function checks authentication is enabled.
         """
@@ -994,7 +983,6 @@ class Audit:
         )
 
     def audit_limit_exclude_auth(server: Server) -> Rule:
-
         """
         This function checks exclusions for authentication.
         """
@@ -1020,7 +1008,6 @@ class Audit:
         )
 
     def audit_webproxy_number(server: Server) -> Rule:
-
         """
         This function checks exclusions for authentication.
         """
@@ -1036,7 +1023,6 @@ class Audit:
         )
 
     def audit_security(server: Server) -> Rule:
-
         """
         This function checks the security configuration.
         """
@@ -1052,7 +1038,6 @@ class Audit:
         )
 
     def audit_debug(server: Server) -> Rule:
-
         """
         This function checks the debug configuration.
         """
@@ -1068,7 +1053,6 @@ class Audit:
         )
 
     def audit_blacklist(server: Server) -> Rule:
-
         """
         This function checks the blacklist configuration.
         """
@@ -1085,7 +1069,6 @@ class Audit:
         )
 
     def audit_smtp_password(server: Server) -> Rule:
-
         """
         This function checks the SMTP password protection.
         """
@@ -1105,7 +1088,6 @@ class Audit:
         )
 
     def audit_log_level(server: Server) -> Rule:
-
         """
         This function checks the log level.
         """
@@ -1121,7 +1103,6 @@ class Audit:
         )
 
     def audits_module_path(server: Server) -> Rule:
-
         """
         This function checks the modules paths.
         """
@@ -1138,7 +1119,6 @@ class Audit:
             )
 
     def audits_scripts_logs(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the configuration of the script log.
         """
@@ -1155,7 +1135,6 @@ class Audit:
             )
 
     def audits_scripts_stderr_content_type(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the configuration of the script stderr content
         type.
@@ -1174,7 +1153,6 @@ class Audit:
             )
 
     def audits_scripts_content_type(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the configuration of the script content type.
         """
@@ -1192,7 +1170,6 @@ class Audit:
             )
 
     def audits_scripts_path(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the configuration of the script path.
         """
@@ -1212,7 +1189,6 @@ class Audit:
             delattr(script, "path_is_defined")
 
     def audits_launcher(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the configuration of the script launcher.
         """
@@ -1230,7 +1206,6 @@ class Audit:
             )
 
     def audit_admin_account(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the admin password.
         """
@@ -1260,7 +1235,6 @@ class Audit:
         )
 
     def get_owner(filename: str) -> str:
-
         """
         This function return the owner of a file.
         """
@@ -1282,7 +1256,6 @@ class Audit:
             return getpwuid(stat(filename).st_uid).pw_name
 
     def audits_file_owner(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the files owner.
         """
@@ -1352,7 +1325,6 @@ class Audit:
                 )
 
     def get_permissions(filename: str) -> str:
-
         """
         This function returns the file permissions.
         """
@@ -1362,7 +1334,6 @@ class Audit:
     def _audits_directory_permissions(
         server: Server, secure_paths: Set[str]
     ) -> Iterator[Rule]:
-
         """
         This function checks owner and permissions on bin directory.
         """
@@ -1412,7 +1383,6 @@ class Audit:
             )
 
     def audits_timeout(server: Server) -> Iterator[Rule]:
-
         """
         This function checks scripts timeout.
         """
@@ -1429,7 +1399,6 @@ class Audit:
             )
 
     def audits_file_rights(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the files rights.
         """
@@ -1465,8 +1434,6 @@ class Audit:
         r_filenames.append(join(current_dir, "config", "server.ini"))
         r_filenames.append(join(current_dir, "config", "server.json"))
 
-        # for dirname_ in (server_path, current_dir):
-
         r_filenames += [
             file.path
             for file in server.pages.js_paths.values()
@@ -1545,7 +1512,6 @@ class Audit:
                 )
 
     def audit_export_configuration(server: Server) -> Iterator[Rule]:
-
         """
         This function checks the export configuration file.
         """
@@ -1562,7 +1528,6 @@ class Audit:
         )
 
     def log_rule(rule: Rule, logs: Logs) -> None:
-
         """
         This function log rule.
         """
@@ -1590,7 +1555,6 @@ class Audit:
             logs.critical(log)
 
     def run(server: Server) -> List[Rule]:
-
         """
         This function run audit and checks.
         """
@@ -1611,7 +1575,6 @@ class Audit:
         return rules
 
     def check_for_updates(logs: Logs) -> None:
-
         """
         This function runs in a thread indefinitely, it checks the version
         and the latest published version of WebScripts every hour.
@@ -1632,7 +1595,6 @@ class Audit:
         version = [int(i) for i in str_version.split(".")]
 
         def get_latest() -> str:
-
             """
             This function request github api and return the latest version.
             """
@@ -1676,90 +1638,31 @@ class FilesIntegrity:
     """
 
     def __init__(self, server: Server):
-        # temp = environ.get("TEMP") or environ.get("TMP") or environ.get("TMPDIR") or (r"C:\temp" if exists(r"C:\temp") else r"C:\tmp") if Audit.is_windows else ("/tmp" if exists("/tmp") else '/var/tmp')
-        # /usr/tmp
-
         self.logs = server.logs
         self.temp = _get_default_tempdir()
 
-        self.webscripts_filename = self.get_checks_filename(
+        self.webscripts_filename = self.get_hardening_filename(
             "webscripts_file_integrity.json"
         )
-        # webscripts_filenames = (
-        #     join(directory, ),
-        #     join(server_path, "webscripts_file_integrity.json"),
-        # )
-        # for path in webscripts_filenames:
-        #     if exists(path):
-        #          = path
-        #         break
-        # else:
-        #     logs.critical(
-        #         "webscripts_file_integrity.json not found ! "
-        #         "Build it in temp file, is not recommended !"
-        #         " Install is not secure !"
-        #     )
-        #     filename = self.webscripts_filename = join(temp, "webscripts_file_integrity.json")
-        #     if not exists(filename):
-        #         with open(filename, 'wb') as file:
-        #             file.write(b'{}')
 
-        self.uploads_filename = self.get_checks_filename(
+        self.uploads_filename = self.get_hardening_filename(
             "uploads_file_integrity.json"
         )
-        # uploads_filenames = (
-        #     join(directory, "uploads_file_integrity.json"),
-        #     join(server_path, "uploads_file_integrity.json"),
-        # )
-        # for path in uploads_filenames:
-        #     if exists(path):
-        #         self.uploads_filename = path
-        #         break
-        # else:
-        #     logs.critical(
-        #         "uploads_file_integrity.json not found ! "
-        #         "Build it in temp file, is not recommended !"
-        #         " Install is not secure !"
-        #     )
-        #     filename = self.uploads_filename = join(temp, "uploads_file_integrity.json")
-        #     if not exists(filename):
-        #         with open(filename, 'wb') as file:
-        #             file.write(b'{}')
 
-        self.logs_filename = self.get_checks_filename("logs_checks.json")
-
-        # logs_filenames = (
-        #     join(directory, "logs_checks.json"),
-        #     join(server_path, "logs_checks.json"),
-        # )
-        # for path in logs_filenames:
-        #     if exists(path):
-        #         self.logs_filename = path
-        #         break
-        # else:
-        #     logs.critical(
-        #         "logs_checks.json not found ! "
-        #         "Build it in temp file, is not recommended !"
-        #         " Install is not secure !"
-        #     )
-        #     filename = self.logs_filename = join(temp, "logs_checks.json")
-        #     if not exists(filename):
-        #         with open(filename, 'wb') as file:
-        #             file.write(b'{}')
+        self.logs_filename = self.get_hardening_filename("logs_checks.json")
 
         self.temp_logs_files = {}
         self.server = server
         self.hashes = {}
 
-    def get_checks_filename(self, filename: str) -> str:
-
+    def get_hardening_filename(self, filename: str) -> str:
         """
         This function returns the path of the filename.
         """
 
         filenames = (
-            join(Audit.current_dir, filename),
-            join(server_path, "integrity", filename),
+            join(Audit.current_dir, "hardening", filename),
+            join(server_path, "hardening", filename),
         )
 
         for path in filenames:
@@ -1768,7 +1671,7 @@ class FilesIntegrity:
                 break
         else:
             self.logs.critical(
-                f"{filename} not found ! "
+                repr(filename) + " not found ! "
                 "Build it in temp file, is not recommended !"
                 " Install is not secure !"
             )
@@ -1788,7 +1691,6 @@ class FilesIntegrity:
     def get_old_files(
         self, filename: str, hash_: str
     ) -> Tuple[Dict[str, str], Dict[str, Dict[str, str]]]:
-
         """
         This function returns file data to check integrity
         from JSON file (previous check).
@@ -1813,13 +1715,11 @@ class FilesIntegrity:
         return to_yield, files
 
     def get_files(self) -> Dict[str, Dict[str, str]]:
-
         """
         This functions gets used files.
         """
 
         def build_file(path: str) -> Dict[str, str]:
-
             """
             This function makes file JSON object from path.
             """
@@ -1834,7 +1734,7 @@ class FilesIntegrity:
             return {
                 "path": path,
                 "sha512": newhash("sha512", data).hexdigest(),
-                "whirlpool": newhash("whirlpool", data).hexdigest(),
+                "sha3_512": newhash("sha3_512", data).hexdigest(),
                 "size": metadata.st_size,
                 "modification": strftime(
                     "%Y-%m-%d %H:%M:%S", localtime(metadata.st_mtime)
@@ -1894,18 +1794,6 @@ class FilesIntegrity:
         for template in templates:
             files[f"template {basename(template)}"] = build_file(template)
 
-        # module_path = join(server_path, "modules")
-        # for filename, path in get_files_recursive(module_path):
-        #     files[f"server modules {filename}"] = build_file(
-        #         join(module_path, path)
-        #     )
-
-        # module_path = join(Audit.current_dir, "modules")
-        # for filename, path in get_files_recursive(module_path):
-        #     files[f"current modules {filename}"] = build_file(
-        #         join(module_path, path)
-        #     )
-
         for name, module in pages.packages.__dict__.items():
             if isinstance(module, ModuleType):
                 files[f"modules {name}"] = build_file(
@@ -1920,7 +1808,6 @@ class FilesIntegrity:
 
         for base in (server_path, "."):
             for directory in configuration.cgi_path:
-
                 full_path = join(base, directory)
                 if not exists(full_path):
                     continue
@@ -1934,7 +1821,6 @@ class FilesIntegrity:
         return files
 
     def check_webscripts_file_integrity(self) -> Iterator[Dict[str, str]]:
-
         """
         This function compares old files data to new files data.
         """
@@ -1958,21 +1844,20 @@ class FilesIntegrity:
                 # you have a weak configuration (WebScripts server
                 # research files).
                 ("sha512", "ZZ", "XX", 10),
-                ("whirlpool", "ZZ", "XX", 10),
+                ("sha3_512", "ZZ", "XX", 10),
                 ("size", -1, -2, 10),
                 # if the file changes, these three checks should fail.
                 ("modification", "~~", "!!", 10),
             ):
-
                 old = data.get(check, old_default)
                 new = new_data.get(check, new_default)
 
                 if old != new:
-                    self.logs.critical(f"Code file: {file} is compromised.")
+                    self.logs.critical(f"Code file: {file!r} is compromised.")
                     yield {
                         "File": file,
                         "Reason": (
-                            f"New {check} for '{file}' "
+                            f"New {check} for {file!r} "
                             f"(Old: {old if old != old_default else None},"
                             f" New: {new if new != new_default else None})"
                         ),
@@ -1980,18 +1865,17 @@ class FilesIntegrity:
                     }
 
         for file, data in new_files.items():
-            self.logs.critical(f"Code file: {file} is compromised.")
+            self.logs.critical(f"Code file: {file!r} is compromised.")
             yield {
                 "File": file,
                 "Reason": (
-                    f"A new file is detected: '{file}' "
+                    f"A new file is detected: {file!r} "
                     f"(Last modification: {data.get('modification')})"
                 ),
                 "Score": 5,
             }
 
     def check_data_file_integrity(self) -> Iterator[Dict[str, str]]:
-
         """
         This function checks uploads file integrity
         (uploads can not be changed from WebScripts Server).
@@ -2041,9 +1925,7 @@ class FilesIntegrity:
                 or data.get("modification", "") != modif
                 or hash_ != data.get("hash", "")
             ):
-                self.logs.warning(
-                    f"Database file: '{file}' has been modified."
-                )
+                self.logs.warning(repr(name) + " has been modified.")
                 yield {
                     "File": name,
                     "Reason": "A database has been modified.",
@@ -2111,7 +1993,6 @@ class FilesIntegrity:
             }
 
     def check_logs_files(self) -> Iterator[Dict[str, str]]:
-
         """
         This function checks logs file.
         """
@@ -2126,22 +2007,10 @@ class FilesIntegrity:
         if to_yield:
             yield to_yield
 
-        # files = [logfile for path in environ["WEBSCRIPTS_LOGS_PATH"].split(":") if isdir(path) for logfile in scandir(path)]
         files = [logfile for logfile in self.server.configuration.log_files]
 
-        # if isdir("logs"):
-        #     self.logs.info("Current logs directory found...")
-        #     files.extend(scandir("logs"))
-
         for filename in files:
-            # basefilename = basename(filename)
-            if (
-                isfile(filename)
-                # and len(basefilename) > 3
-                # and basefilename[:2].isdigit()
-                # and basefilename[2] == "-"
-                # and basefilename.endswith(".logs")
-            ):
+            if isfile(filename):
                 self.logs.debug(f"Check log file: '{filename}'...")
                 metadata = stat(filename)
                 size = metadata.st_size
@@ -2188,7 +2057,6 @@ class FilesIntegrity:
                 self.logs.debug(f"Log file: '{filename}' is checked.")
 
     def save(self) -> None:
-
         """
         This function saves data to check file integrity.
         """
@@ -2215,7 +2083,6 @@ class FilesIntegrity:
     def check_logs_ok(
         path: str, temp_file: TemporaryFile, metadata: stat_result
     ) -> bool:
-
         """
         This function checks the log file integrity.
         """
@@ -2234,12 +2101,7 @@ class FilesIntegrity:
         read_check_log = temp_file.readline
         write_check_log = temp_file.write
 
-        if (
-            temp_metadata.st_size
-            > metadata.st_size
-            # or temp_metadata.st_mtime > metadata.st_mtime
-            # or temp_metadata.st_ctime < metadata.st_ctime
-        ):
+        if temp_metadata.st_size > metadata.st_size:
             restore(temp_file)
             return False
 
@@ -2266,7 +2128,6 @@ class FilesIntegrity:
 
 
 def sha512sum(path: str, length: int = DEFAULT_BUFFER_SIZE) -> str:
-
     """
     This function returns the SHA512 of a file.
     """
@@ -2288,13 +2149,12 @@ def daemon_func(
     server: Server,
     file_integrity: FilesIntegrity,
 ) -> None:
-
     """
     This function implements a daemon thread to
     check WebScripts version, update and integrity.
     """
 
-    sleep(120)  # No SMTP error: "SmtpError: to many connections"
+    sleep(120)  # Bypass SMTP error: "SmtpError: to many connections"
     logs = server.logs
     files = []
     text = ""
@@ -2332,7 +2192,6 @@ def daemon_func(
 
         file_integrity.save()
 
-        # if [file for file in files if file["Score"] == 10]:
         if any([file["Score"] >= 5 for file in files]):
             lengths = {
                 "File": {"length": 24},
@@ -2371,7 +2230,6 @@ def daemon_func(
 
 
 def get_files_recursive(path: str) -> Iterator[Tuple[str, str]]:
-
     """
     This function returns path and file names recursively.
     """
@@ -2387,7 +2245,6 @@ def get_files_recursive(path: str) -> Iterator[Tuple[str, str]]:
 
 
 def main(server: Server) -> Report:
-
     """
     The main function to perform WebScripts Server hardening audit.
     """
@@ -2411,13 +2268,17 @@ def main(server: Server) -> Report:
     report.as_html()
     report.as_text()
 
-    with open("audit.json", "w") as file:
+    with open(
+        file_integrity.get_hardening_filename("audit.json"), "w"
+    ) as file:
         file.write(report.reports_json)
 
-    with open("audit.html", "w") as file:
+    with open(
+        file_integrity.get_hardening_filename("audit.html"), "w"
+    ) as file:
         file.write(report.reports_html)
 
-    with open("audit.txt", "w") as file:
+    with open(file_integrity.get_hardening_filename("audit.txt"), "w") as file:
         file.write(report.reports_text)
 
     logs.debug("Start a thread to send hardening report...")
