@@ -3,7 +3,7 @@
 
 ###################
 #    This file may display the license and copyright of WebScripts
-#    Copyright (C) 2021, 2022  Maurice Lambert
+#    Copyright (C) 2021, 2022, 2023  Maurice Lambert
 
 #    This program is free software: you can redistribute it and/or modify
 #    it under the terms of the GNU General Public License as published by
@@ -20,7 +20,7 @@
 ###################
 
 """
-This tool run scripts and display the result in a Web Interface.
+This tool runs CLI scripts and displays output in a Web Interface.
 
 This file may display the license and copyright of WebScripts.
 """
@@ -30,14 +30,14 @@ __author__ = "Maurice Lambert"
 __author_email__ = "mauricelambert434@gmail.com"
 __maintainer__ = "Maurice Lambert"
 __maintainer_email__ = "mauricelambert434@gmail.com"
-__description__ = """This tool run scripts and display the result in a Web Interface.
+__description__ = """#    This tool runs CLI scripts and displays output in a Web Interface.
 
 This file may display the license and copyright of WebScripts."""
 __license__ = "GPL-3.0 License"
 __url__ = "https://github.com/mauricelambert/WebScripts"
 
 copyright = """
-WebScripts  Copyright (C) 2021, 2022  Maurice Lambert
+WebScripts  Copyright (C) 2021, 2022, 2023  Maurice Lambert
 This program comes with ABSOLUTELY NO WARRANTY.
 This is free software, and you are welcome to redistribute it
 under certain conditions.
@@ -53,7 +53,6 @@ from os import chdir
 
 
 def main() -> int:
-
     """
     Main function to display license and copyright of WebScripts.
     """
